@@ -6,6 +6,7 @@
 #include <string.h>
 
 #include "app.h"
+#include "e-phone-entry.h"
 
 #include <gnomebt-chooser.h>
 
@@ -297,25 +298,27 @@ destroy_send_dialog (GtkDialog *dialog, GladeXML *ui)
 static void
 set_send_sensitivity (GtkWidget *w, GladeXML *ui)
 {
-	GtkEntry *entry;
+	EPhoneEntry *entry;
 	GtkTextView *view;
 	GtkTextBuffer *buf;
 	GtkWidget *sendbutton;
 	GtkLabel *left;
 	gint l;
 	gchar *work;
+	gchar *text;
 
 	left = GTK_LABEL (glade_xml_get_widget (ui, "charsleft"));
 	view = GTK_TEXT_VIEW (glade_xml_get_widget (ui, "messagebody"));
 	buf = gtk_text_view_get_buffer (view);
-	entry = GTK_ENTRY (glade_xml_get_widget (ui, "recipient"));
+	entry = E_PHONE_ENTRY (glade_xml_get_widget (ui, "recipient"));
 	sendbutton = GTK_WIDGET (glade_xml_get_widget (ui, "sendbutton"));
 
 	l = gtk_text_buffer_get_char_count (buf);
+	text = e_phone_entry_get_number (entry);
 
 	gtk_widget_set_sensitive (sendbutton,
-			l > 0 && l <= MAX_MESSAGE_LENGTH &&
-			(*gtk_entry_get_text (entry) != 0));
+			l > 0 && l <= MAX_MESSAGE_LENGTH && text != NULL);
+	g_free (text);
 
 	if (l > MAX_MESSAGE_LENGTH) {
 		gtk_label_set_text (left, _("Message too long!"));
@@ -327,27 +330,36 @@ set_send_sensitivity (GtkWidget *w, GladeXML *ui)
 	}
 }
 
+static void
+phone_number_changed (GtkWidget *entry, char *phone_number, GladeXML *ui)
+{
+	set_send_sensitivity (entry, ui);
+}
+
 static void
 send_message (GtkWidget *w, GladeXML *ui)
 {
 	GtkTextBuffer *buf;
 	GtkTextView *view;
-	GtkEntry *entry;
+	EPhoneEntry *entry;
 	GtkDialog *dialog;
 	GtkTextIter s, e;
+	gchar *number;
 
 	MyApp *app = (MyApp *) g_object_get_data (G_OBJECT (ui), "app");
 
 	dialog = GTK_DIALOG (glade_xml_get_widget (ui, "send_dialog"));
 	view = GTK_TEXT_VIEW (glade_xml_get_widget (ui, "messagebody"));
 	buf = gtk_text_view_get_buffer (view);
-	entry = GTK_ENTRY (glade_xml_get_widget (ui, "recipient"));
+	entry = E_PHONE_ENTRY (glade_xml_get_widget (ui, "recipient"));
 
 	gtk_text_buffer_get_start_iter (buf, &s);
 	gtk_text_buffer_get_end_iter (buf, &e);
+	number = e_phone_entry_get_number (entry);
 	phonemgr_listener_queue_message (app->listener,
-			gtk_entry_get_text (entry),
+			number,
 			gtk_text_buffer_get_text (buf, &s, &e, FALSE));
+	g_free (number);
 
 	gtk_widget_hide (GTK_WIDGET (dialog));
 }
@@ -396,8 +408,8 @@ create_send_dialog (MyApp *app, GtkDialog *parent, const gchar *recip)
 	g_signal_connect_swapped (G_OBJECT (w), "clicked",
 			G_CALLBACK (gtk_widget_hide), (gpointer) dialog);
 
-	g_signal_connect (G_OBJECT (entry), "changed",
-			G_CALLBACK (set_send_sensitivity), (gpointer) ui);
+	g_signal_connect (G_OBJECT (entry), "phone-changed",
+			G_CALLBACK (phone_number_changed), (gpointer) ui);
 	g_signal_connect (G_OBJECT (buf), "changed",
 			G_CALLBACK (set_send_sensitivity), (gpointer) ui);
 
@@ -476,6 +488,22 @@ ui_init (MyApp *app)
 			NULL, NULL);
 }
 
+void
+ui_hide (MyApp *app)
+{
+	GtkWidget *w;
+	GdkDisplay *display;
+
+	w = glade_xml_get_widget (app->ui, "prefs_window");
+	display = gtk_widget_get_display (w);
+	gtk_widget_hide (w);
+
+	w = glade_xml_get_widget (app->ui, "send_dialog");
+	gtk_widget_hide (w);
+
+	gdk_display_sync (display);
+}
+
 void
 show_prefs_window (MyApp *app)
 {
@@ -484,13 +512,6 @@ show_prefs_window (MyApp *app)
 	gtk_widget_show (prefs);
 }
 
-static size_t
-my_strftime(char *s, size_t max, const char  *fmt,  const
-           struct tm *tm)
-{
-	return strftime(s, max, fmt, tm);
-}
-
 gboolean
 dequeue_message (MyApp *app)
 {
@@ -501,7 +522,7 @@ dequeue_message (MyApp *app)
 	GtkLabel *l_sender, *l_sent;
 	GtkTextBuffer *buf;
 	gchar work[64];
-	struct tm *time_tm;
+	GDate *date;
 	GladeXML *ui;
 	GtkWidget *w;
 
@@ -545,8 +566,10 @@ dequeue_message (MyApp *app)
 	gtk_text_buffer_set_text (buf, msg->message, strlen (msg->message));
 	gtk_label_set_text (l_sender, msg->sender);
 
-	time_tm = localtime ((time_t*)&msg->timestamp);
-	my_strftime (work, 64, "%X %x", time_tm);
+	date = g_date_new ();
+	g_date_set_time (date, msg->timestamp);
+	g_date_strftime (work, 64, "%X %x", date);
+	g_date_free (date);
 	gtk_label_set_text (l_sent, work);
 
 	gtk_widget_show_all (GTK_WIDGET (dialog));
